@@ -33,10 +33,21 @@ git2rdata:::set_local_locale(old_locale)
 sorted_test_data$test_character <- enc2utf8(sorted_test_data$test_character)
 rownames(sorted_test_data) <- NULL
 
+sorted_test_data_6 <- sorted_test_data
+sorted_test_data_6$test_numeric <- signif(sorted_test_data_6$test_numeric, 6)
+
+sorted_test_data_4 <- sorted_test_data
+sorted_test_data_4$test_numeric <- signif(sorted_test_data_4$test_numeric, 4)
+
+
 test_subset <- head(test_data, ceiling(test_n / 2))
 
 sorted_test_subset <- test_subset[order(test_subset$test_Date), ]
 rownames(sorted_test_subset) <- NULL
+sorted_test_subset_6 <- sorted_test_subset
+sorted_test_subset_6$test_numeric <- signif(
+  sorted_test_subset_6$test_numeric, 6
+)
 
 test_na <- test_data
 for (i in seq_along(test_na)) {
@@ -46,5 +57,6 @@ old_locale <- git2rdata:::set_c_locale()
 sorted_test_na <- test_na[
   order(test_na$test_Date, test_na$test_integer, test_na$test_numeric),
 ]
+sorted_test_na$test_numeric <- signif(sorted_test_na$test_numeric, 6)
 git2rdata:::set_local_locale(old_locale)
 rownames(sorted_test_na) <- NULL
