@@ -13,10 +13,13 @@ test_that("rm_data & prune_meta", {
   expect_error(prune_meta(root), root)
   dir.create(root)
   expect_null(prune_meta(root, path = "junk"))
-  write_vc(test_data, file = "test", root = root, sorting = "test_Date")
+  write_vc(
+    test_data, file = "test", root = root, sorting = "test_Date",
+    digits = 6
+  )
   write_vc(
     test_data, file = file.path("a", "verbose"), root = root,
-    sorting = "test_Date", optimize = FALSE
+    sorting = "test_Date", optimize = FALSE, digits = 6
   )
 
   current <- list.files(root, recursive = TRUE)
@@ -42,13 +45,15 @@ test_that("rm_data & prune_meta", {
   expect_identical(rm_data(root, path = "."), character(0))
   expect_identical(list.files(root, recursive = TRUE), current)
 
-  write_vc(test_data, file = "test1", root = root, sorting = "test_Date")
+  write_vc(
+    test_data, file = "test1", root = root, sorting = "test_Date", digits = 6
+  )
   junk <- write_vc(
-    test_data, file = "test2", root = root, sorting = "test_Date"
+    test_data, file = "test2", root = root, sorting = "test_Date", digits = 6
   )
   write_vc(
     test_data, file = file.path("a", "test2"), root = root,
-    sorting = "test_Date"
+    sorting = "test_Date", digits = 6
   )
   meta_data <- yaml::read_yaml(file.path(root, junk[2]))
   meta_data[["..generic"]] <- NULL
