@@ -8,7 +8,7 @@ git2r::add(root, ".gitignore")
 commit(root, "initial commit")
 expect_identical(rm_data(root, "."), character(0))
 untracked <- write_vc(
-  test_data, file = "untracked", root = root, sorting = "test_Date"
+  test_data, file = "untracked", root = root, sorting = "test_Date", digits = 6
 )
 expect_equal(
   status(root, ignored = TRUE),
@@ -19,21 +19,19 @@ expect_equal(
   check.attributes = FALSE
 )
 expect_equal(
-  stored <- read_vc(file = "untracked", root = root),
-  sorted_test_data,
+  stored <- read_vc(file = "untracked", root = root), sorted_test_data_6,
   check.attributes = FALSE
 )
 for (i in colnames(stored)) {
   expect_equal(
-    stored[[i]],
-    sorted_test_data[[i]],
-    label = paste0("stored$", i),
+    stored[[i]], sorted_test_data_6[[i]], label = paste0("stored$", i),
     expected.label = paste0("sorted_test_data$", i)
   )
 }
 
 staged <- write_vc(
-  test_data, file = "staged", root = root, sorting = "test_Date", stage = TRUE
+  test_data, file = "staged", root = root, sorting = "test_Date", stage = TRUE,
+  digits = 6
 )
 expect_equal(
   status(root, ignored = TRUE),
@@ -44,21 +42,19 @@ expect_equal(
   check.attributes = FALSE
 )
 expect_equal(
-  stored <- read_vc(file = "staged", root = root),
-  sorted_test_data,
+  stored <- read_vc(file = "staged", root = root), sorted_test_data_6,
   check.attributes = FALSE
 )
 for (i in colnames(stored)) {
   expect_equal(
-    stored[[i]],
-    sorted_test_data[[i]],
-    label = paste0("stored$", i),
+    stored[[i]], sorted_test_data_6[[i]], label = paste0("stored$", i),
     expected.label = paste0("sorted_test_data$", i)
   )
 }
 
 ignored <- write_vc(
-  test_data, file = "ignore", root = root, sorting = "test_Date", stage = TRUE
+  test_data, file = "ignore", root = root, sorting = "test_Date", stage = TRUE,
+  digits = 6
 )
 expect_equal(
   status(root, ignored = TRUE),
@@ -69,21 +65,18 @@ expect_equal(
   check.attributes = FALSE
 )
 expect_equal(
-  stored <- read_vc(file = "ignore", root = root),
-  sorted_test_data,
+  stored <- read_vc(file = "ignore", root = root), sorted_test_data_6,
   check.attributes = FALSE
 )
 for (i in colnames(stored)) {
   expect_equal(
-    stored[[i]],
-    sorted_test_data[[i]],
-    label = paste0("stored$", i),
+    stored[[i]], sorted_test_data_6[[i]], label = paste0("stored$", i),
     expected.label = paste0("sorted_test_data$", i)
   )
 }
 
 forced <- write_vc(
-  test_data, file = file.path("forced", "force"), root = root,
+  test_data, file = file.path("forced", "force"), root = root, digits = 6,
   sorting = "test_Date", stage = TRUE, force = TRUE
 )
 expect_equal(
@@ -98,22 +91,18 @@ expect_equal(
 )
 expect_equal(
   stored <- read_vc(file = file.path("forced", "force"), root = root),
-  sorted_test_data,
-  check.attributes = FALSE
+  sorted_test_data_6, check.attributes = FALSE
 )
 for (i in colnames(stored)) {
   expect_equal(
-    stored[[i]],
-    sorted_test_data[[i]],
-    label = paste0("stored$", i),
+    stored[[i]], sorted_test_data_6[[i]], label = paste0("stored$", i),
     expected.label = paste0("sorted_test_data$", i)
   )
 }
 commit(root, "add data")
 
 staged <- write_vc(
-  test_subset,
-  file = "staged", root = root, stage = FALSE
+  test_subset, file = "staged", root = root, stage = FALSE, digits = 6
 )
 expect_equal(
   status(root, ignored = TRUE),
@@ -124,22 +113,18 @@ expect_equal(
   check.attributes = FALSE
 )
 expect_equal(
-  stored <- read_vc(file = "staged", root = root),
-  sorted_test_subset,
+  stored <- read_vc(file = "staged", root = root), sorted_test_subset_6,
   check.attributes = FALSE
 )
 for (i in colnames(stored)) {
   expect_equal(
-    stored[[i]],
-    sorted_test_subset[[i]],
-    label = paste0("stored$", i),
+    stored[[i]], sorted_test_subset_6[[i]], label = paste0("stored$", i),
     expected.label = paste0("sorted_test_subset$", i)
   )
 }
 
 staged <- write_vc(
-  test_subset,
-  file = "staged", root = root, stage = TRUE
+  test_subset, file = "staged", root = root, stage = TRUE, digits = 6
 )
 expect_equal(
   status(root, ignored = TRUE),
@@ -150,15 +135,12 @@ expect_equal(
   check.attributes = FALSE
 )
 expect_equal(
-  stored <- read_vc(file = "staged", root = root),
-  sorted_test_subset,
+  stored <- read_vc(file = "staged", root = root), sorted_test_subset_6,
   check.attributes = FALSE
 )
 for (i in colnames(stored)) {
   expect_equal(
-    stored[[i]],
-    sorted_test_subset[[i]],
-    label = paste0("stored$", i),
+    stored[[i]], sorted_test_subset_6[[i]], label = paste0("stored$", i),
     expected.label = paste0("sorted_test_subset$", i)
   )
 }
@@ -167,13 +149,11 @@ commit(root, "update data")
 expect_null(prune_meta(root, path = "junk"))
 
 staged <- write_vc(
-  test_data,
-  file = "staged", root = root, stage = TRUE
+  test_data, file = "staged", root = root, stage = TRUE, digits = 6
 )
 current <- list.files(git2r::workdir(root), recursive = TRUE)
 expect_identical(
-  rm_data(root = root, path = "."),
-  file.path("forced", "force.tsv")
+  rm_data(root = root, path = "."), file.path("forced", "force.tsv")
 )
 expect_identical(
   current[!current %in% list.files(git2r::workdir(root), recursive = TRUE)],
@@ -200,8 +180,7 @@ expect_null(prune_meta(root, path = "."))
 git2r::reset(git2r::last_commit(root), reset_type = "hard", path = ".")
 
 staged <- write_vc(
-  test_data,
-  file = "staged", root = root, stage = TRUE
+  test_data, file = "staged", root = root, stage = TRUE
 )
 expect_identical(
   rm_data(root = root, path = ".", type = "m"),
@@ -225,8 +204,7 @@ expect_identical(
 git2r::reset(git2r::last_commit(root), reset_type = "hard", path = ".")
 
 staged <- write_vc(
-  test_data,
-  file = "staged", root = root, stage = TRUE
+  test_data, file = "staged", root = root, stage = TRUE
 )
 expect_identical(
   rm_data(root = root, path = ".", type = "i", stage = TRUE),
@@ -250,12 +228,10 @@ expect_identical(
 git2r::reset(git2r::last_commit(root), reset_type = "hard", path = ".")
 
 ignored <- write_vc(
-  test_data, file = "ignore", root = root, sorting = "test_Date", stage = TRUE
-)
-staged <- write_vc(
-  test_data,
-  file = "staged", root = root, stage = TRUE
+  test_data, file = "ignore", root = root, sorting = "test_Date", stage = TRUE,
+  digits = 6
 )
+staged <- write_vc(test_data, file = "staged", root = root, stage = TRUE)
 expect_identical(
   rm_data(root = root, path = ".", type = "all", stage = TRUE),
   c(
